==========
User guide
==========

.. toctree::
   :maxdepth: 1
   :hidden:

   concepts/index
   getting-started
   install/index
   configuration/index
   tasks/index
   cheatsheet
   troubleshooting

:doc:`Home <../index>` | :doc:`Concepts <concepts/index>` | :doc:`Getting started <getting-started>` | :doc:`Installation <install/index>` | :doc:`Configuration <configuration/index>` | :doc:`Tasks <tasks/index>` | :ref:`Additional resources <addl-resources>`

**Get started**

* :doc:`See what conda is and what it does <../index>`.
* :doc:`Learn conda concepts and fundamentals <concepts/index>`.
* :doc:`Create your first conda project in 20 minutes <getting-started>`.
* :doc:`View system requirements and installation directions <install/index>`.


**Dive deeper**

* :doc:`Configure your conda files <configuration/index>`.
* Follow the :doc:`tasks <tasks/index>` to :doc:`manage conda environments <tasks/manage-environments>`, :doc:`channels <tasks/manage-channels>`, :doc:`packages<tasks/manage-pkgs>`, and more.


.. _addl-resources:

**Additional resources**

* :doc:`Cheat sheet <cheatsheet>`.
* :doc:`Troubleshooting <troubleshooting>`.
